### Name: sir.cont
### Title: Ventilation status in intensive care unit patients
### Aliases: sir.cont
### Keywords: datasets

### ** Examples

data(sir.cont)

# Matrix of possible transitions
tra <- matrix(ncol=3,nrow=3,TRUE)
tra[3,1:2] <- FALSE

# Computation of the Nelson-Aalen estimates
  na.cont <- mvna(sir.cont,c("0","1","2"),tra,"cens")

  xyplot(na.cont,tr.choice=c("0 2","1 2"),aspect=1,
       strip=strip.custom(bg="white",
         factor.levels=c("No ventilation -- Discharge/Death",
           "Ventilation -- Discharge/Death"),
         par.strip.text=list(cex=0.9)),
       scales=list(alternating=1),xlab="Days",
       ylab="Nelson-Aalen estimates")

## Not run: 
  # Bootstrap
  # Bootstrap statistics. Works for one transition at a time
  na.boot <- function(data,index,state.names,tra,cens.name,ctr) {
  temp <- mvna(data[index,],state.names,tra,
               cens.name,tr.choice=ctr)[[ctr]]$var1
  return(temp)
  }

  # Matrix of possible transitions
  tra <- matrix(ncol=3,nrow=3,TRUE)
  tra[3,1:2] <- FALSE

  # Test
  na.boot(sir.cont,1:nrow(sir.cont),
          c("0","1","2"),tra,"cens","0 2")

  library(boot)
  nb <- 10 ## nb=1000
  var.boot <- boot(sir.cont,na.boot,nb,
                   state.names=c("0","1","2"),
                   tra=tra,cens.name="cens",ctr="0 2",sim="permutation")

  m <- apply(var.boot$t,MARGIN=2,FUN=mean)
## End(Not run)



